""" This module loads all the classes from the VTK Common library into its
namespace.  This is a required module."""

from vtkCommonPython import *
